IsabelleClient.Task (isabelle_elixir v0.2.0)

Result of an Isabelle asynchronous server task.

Summary

Functions

Creates a running task struct from an Isabelle task id.

Types

t()

@type t() :: %IsabelleClient.Task{
  id: String.t(),
  notes: [map()],
  result: map() | nil,
  status: :running | :finished | :failed
}

Functions

new(id)

Creates a running task struct from an Isabelle task id.